==> cramr_ui_lib-1.0.2.tar.gz: lib/model/verb_test_model.dart <==
import 'dart:collection';

import 'package:cramr_ui_lib/model/verb.dart';
import 'package:flutter/material.dart';

/// Model class for studying, testing and evaluating the verb. The model should
/// be initialised with the attributes of the [expected] that is being evaluated and
/// with the [pronouns] of the language. The instance also maintains a score
/// representing the amount of correct answers added by using the [add] method.
class VerbTestModel<T extends Verb> with ChangeNotifier {
  // verb under test
  late List<String> _expected;
  late String _infinitive;
  late String _targetLanguageIso;
  late String _translation;

  // ignore: unnecessary_getters_setters
  set expected(List<String> value) {
    _expected = value;
  }

  // Responses for evaluation
  final List<String> _actualItems = [];

  // Pronouns off the bat
  List<String> _pronouns = [];

  // The actual score (right answers)
  int _score = 0;

  int get score => _score; //unmodifiable getter
  List<String> get pronouns => _pronouns; //unmodifiable getter

  // ignore: unnecessary_getters_setters
  List<String> get expected => _expected; //unmodifiable getter

  UnmodifiableListView<String> get items => UnmodifiableListView(_actualItems);

  String get infinitive => _infinitive;
  String get targetLanguageIso => _targetLanguageIso;
  String get translation => _translation;

  /// Initialise the model with the attributes of the [Verb] under test, as well
  /// as the [pronouns] of the language of the verb.
  /// Notifies listeners.
  void initialise(List<String> expected, List<String> pronouns,
      String infinitive, String targetLanguageIso, String translation) {
    _pronouns = pronouns;
    _clearActualsForPronouns();
    _expected = expected;
    _infinitive = infinitive;
    _targetLanguageIso = targetLanguageIso;
    _translation = translation;
    notifyListeners();
  }

  /// Resets the answers already given, for instance when giving another try.
  /// Notifies listeners.
  void reset() {
    _actualItems.clear();
    _clearActualsForPronouns();
    notifyListeners();
  }

  void _clearActualsForPronouns() {
    for (int i = 0; i < _pronouns.length; i++) {
      _actualItems.add("");
    }
  }

  /// Adds the answer ([item]) to the list of answers on the zero-based position
  /// corresponding to the [person] of the conjugation
  void add(String item, int person) {
    _actualItems[person] = item.trim();
    _score = 0;
    for (int i = 0; i < _actualItems.length; i++) {
      if (_actualItems[i] != "" && _actualItems[i] == _expected[i]) {
        _score++;
      }
    }

    notifyListeners();
  }

  /// Returns true if an answer has been submitted for all persons
  bool isComplete() {
    for (int i = 0; i < _actualItems.length; i++) {
      if ("" == _actualItems[i]) {
        return false;
      }
    }
    return true;
  }
}

==> cramr_ui_lib-1.0.7.tar.gz: lib/model/verb_test_model.dart <==
import 'dart:collection';

import 'package:cramr_ui_lib/model/verb.dart';
import 'package:flutter/material.dart';

/// Model class for studying, testing and evaluating the verb. The model should
/// be initialised with the attributes of the [expected] that is being evaluated and
/// with the [pronouns] of the language. The instance also maintains a score
/// representing the amount of correct answers added by using the [add] method.
class VerbTestModel<T extends Verb> with ChangeNotifier {
  // verb under test
  late List<String> _expected;
  late String _infinitive;
  late String _targetLanguageIso;
  late String _translation;
  late String _mode;
  late String _tense;

  // ignore: unnecessary_getters_setters
  set expected(List<String> value) {
    _expected = value;
  }

  // Responses for evaluation
  final List<String> _actualItems = [];

  // Pronouns off the bat
  List<String> _pronouns = [];

  // The actual score (right answers)
  int _score = 0;

  int get score => _score; //unmodifiable getter
  List<String> get pronouns => _pronouns; //unmodifiable getter

  // ignore: unnecessary_getters_setters
  List<String> get expected => _expected; //unmodifiable getter

  UnmodifiableListView<String> get items => UnmodifiableListView(_actualItems);

  String get infinitive => _infinitive;
  String get targetLanguageIso => _targetLanguageIso;
  String get translation => _translation;
  String get mode => _mode;
  String get tense => _tense;

  /// Initialise the model with the attributes of the [Verb] under test, as well
  /// as the [pronouns] of the language of the verb.
  /// Notifies listeners.
  void initialise(
      List<String> expected,
      List<String> pronouns,
      String infinitive,
      String targetLanguageIso,
      String translation,
      String mode,
      String tense) {
    _pronouns = pronouns;
    _clearActualsForPronouns();
    _expected = expected;
    _infinitive = infinitive;
    _targetLanguageIso = targetLanguageIso;
    _translation = translation;
    _mode = mode;
    _tense = tense;
    notifyListeners();
  }

  /// Resets the answers already given, for instance when giving another try.
  /// Notifies listeners.
  void reset() {
    _actualItems.clear();
    _clearActualsForPronouns();
    notifyListeners();
  }

  void _clearActualsForPronouns() {
    for (int i = 0; i < _pronouns.length; i++) {
      _actualItems.add("");
    }
  }

  /// Adds the answer ([item]) to the list of answers on the zero-based position
  /// corresponding to the [person] of the conjugation
  void add(String item, int person) {
    _actualItems[person] = item.trim();
    _score = 0;
    for (int i = 0; i < _actualItems.length; i++) {
      if (_actualItems[i] != "" && _actualItems[i] == _expected[i]) {
        _score++;
      }
    }

    notifyListeners();
  }

  /// Returns true if an answer has been submitted for all persons
  bool isComplete() {
    for (int i = 0; i < _actualItems.length; i++) {
      if ("" == _actualItems[i]) {
        return false;
      }
    }
    return true;
  }
}
